==> estateplat-common-1.2.3-20180208.103700-28-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfZlht.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 租赁合同
 */
@Table(name = "fcjy_clf_zlht")
public class FcjyClfZlht implements InsertVo {
    @Id
    private String zlhtid;//租赁合同id
    private Long zlhtbh;//租赁合同编号
    private String mbid;//模版id
    private String hbh;//户编号
    private Date zlqsrq;//租赁起始日期
    private Date zljsrq;//租赁结束日期
    private Double zjjg;//租金价格
    private Double djjg;//定金价格
    private String fkxs;//付款形式
    private Integer fkqx;//付款期限
    private Integer jfqx;//交付期限
    private Integer zldqtqtcts;//租赁到期提前提出天数
    private Integer zldqtqdfts;//租赁到期提前答复天数
    private Integer jfzzhttqtcts;//甲方终止合同提前提出天数
    private Integer yfzzhttqtcts;//乙方终止合同提前提出天数
    private Double jfwyjbl;//甲方违约金比例
    private Double yfwyjbl;//乙方违约金比例
    private String htzzyd;//合同终止约定
    private Integer bldjqx;//办理登记期限
    private String bldjjg;//办理登记机构
    private String qtyd;//其他约定
    private String fdcjjjgbh;//房地产经纪机构编号
    private String fdcjjrbh;//房地产经纪人编号
    private String zt;//状态

    public String getZlhtid() {
        return zlhtid;
    }

    public void setZlhtid(String zlhtid) {
        this.zlhtid = zlhtid;
    }

    public Long getZlhtbh() {
        return zlhtbh;
    }

    public void setZlhtbh(Long zlhtbh) {
        this.zlhtbh = zlhtbh;
    }

    public String getMbid() {
        return mbid;
    }

    public void setMbid(String mbid) {
        this.mbid = mbid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public Date getZlqsrq() {
        return zlqsrq;
    }

    public void setZlqsrq(Date zlqsrq) {
        this.zlqsrq = zlqsrq;
    }

    public Date getZljsrq() {
        return zljsrq;
    }

    public void setZljsrq(Date zljsrq) {
        this.zljsrq = zljsrq;
    }

    public Double getZjjg() {
        return zjjg;
    }

    public void setZjjg(Double zjjg) {
        this.zjjg = zjjg;
    }

    public Double getDjjg() {
        return djjg;
    }

    public void setDjjg(Double djjg) {
        this.djjg = djjg;
    }

    public String getFkxs() {
        return fkxs;
    }

    public void setFkxs(String fkxs) {
        this.fkxs = fkxs;
    }

    public Integer getFkqx() {
        return fkqx;
    }

    public void setFkqx(Integer fkqx) {
        this.fkqx = fkqx;
    }

    public Integer getJfqx() {
        return jfqx;
    }

    public void setJfqx(Integer jfqx) {
        this.jfqx = jfqx;
    }

    public Integer getZldqtqtcts() {
        return zldqtqtcts;
    }

    public void setZldqtqtcts(Integer zldqtqtcts) {
        this.zldqtqtcts = zldqtqtcts;
    }

    public Integer getZldqtqdfts() {
        return zldqtqdfts;
    }

    public void setZldqtqdfts(Integer zldqtqdfts) {
        this.zldqtqdfts = zldqtqdfts;
    }

    public Integer getJfzzhttqtcts() {
        return jfzzhttqtcts;
    }

    public void setJfzzhttqtcts(Integer jfzzhttqtcts) {
        this.jfzzhttqtcts = jfzzhttqtcts;
    }

    public Integer getYfzzhttqtcts() {
        return yfzzhttqtcts;
    }

    public void setYfzzhttqtcts(Integer yfzzhttqtcts) {
        this.yfzzhttqtcts = yfzzhttqtcts;
    }

    public Double getJfwyjbl() {
        return jfwyjbl;
    }

    public void setJfwyjbl(Double jfwyjbl) {
        this.jfwyjbl = jfwyjbl;
    }

    public Double getYfwyjbl() {
        return yfwyjbl;
    }

    public void setYfwyjbl(Double yfwyjbl) {
        this.yfwyjbl = yfwyjbl;
    }

    public String getHtzzyd() {
        return htzzyd;
    }

    public void setHtzzyd(String htzzyd) {
        this.htzzyd = htzzyd;
    }

    public Integer getBldjqx() {
        return bldjqx;
    }

    public void setBldjqx(Integer bldjqx) {
        this.bldjqx = bldjqx;
    }

    public String getBldjjg() {
        return bldjjg;
    }

    public void setBldjjg(String bldjjg) {
        this.bldjjg = bldjjg;
    }

    public String getQtyd() {
        return qtyd;
    }

    public void setQtyd(String qtyd) {
        this.qtyd = qtyd;
    }

    public String getFdcjjjgbh() {
        return fdcjjjgbh;
    }

    public void setFdcjjjgbh(String fdcjjjgbh) {
        this.fdcjjjgbh = fdcjjjgbh;
    }

    public String getFdcjjrbh() {
        return fdcjjrbh;
    }

    public void setFdcjjrbh(String fdcjjrbh) {
        this.fdcjjrbh = fdcjjrbh;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }
}

==> estateplat-common-1.2.4-20241031.085433-1261-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfZlht.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 租赁合同
 */
@Table(name = "fcjy_clf_zlht")
public class FcjyClfZlht implements InsertVo {
    @Id
    private String zlhtid;//租赁合同id
    private Long zlhtbh;//租赁合同编号
    private String mbid;//模版id
    private String hbh;//户编号
    private Date zlqsrq;//租赁起始日期
    private Date zljsrq;//租赁结束日期
    private Double zjjg;//租金价格
    private Double djjg;//定金价格
    private String fkxs;//付款形式
    private Integer fkqx;//付款期限
    private Integer jfqx;//交付期限
    private Integer zldqtqtcts;//租赁到期提前提出天数
    private Integer zldqtqdfts;//租赁到期提前答复天数
    private Integer jfzzhttqtcts;//甲方终止合同提前提出天数
    private Integer yfzzhttqtcts;//乙方终止合同提前提出天数
    private Double jfwyjbl;//甲方违约金比例
    private Double yfwyjbl;//乙方违约金比例
    private String htzzyd;//合同终止约定
    private Integer bldjqx;//办理登记期限
    private String bldjjg;//办理登记机构
    private String qtyd;//其他约定
    private String fdcjjjgbh;//房地产经纪机构编号
    private String fdcjjrbh;//房地产经纪人编号
    private String zt;//状态
    private String htbz;//合同币种

    public String getZlhtid() {
        return zlhtid;
    }

    public void setZlhtid(String zlhtid) {
        this.zlhtid = zlhtid;
    }

    public Long getZlhtbh() {
        return zlhtbh;
    }

    public void setZlhtbh(Long zlhtbh) {
        this.zlhtbh = zlhtbh;
    }

    public String getMbid() {
        return mbid;
    }

    public void setMbid(String mbid) {
        this.mbid = mbid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public Date getZlqsrq() {
        return zlqsrq;
    }

    public void setZlqsrq(Date zlqsrq) {
        this.zlqsrq = zlqsrq;
    }

    public Date getZljsrq() {
        return zljsrq;
    }

    public void setZljsrq(Date zljsrq) {
        this.zljsrq = zljsrq;
    }

    public Double getZjjg() {
        return zjjg;
    }

    public void setZjjg(Double zjjg) {
        this.zjjg = zjjg;
    }

    public Double getDjjg() {
        return djjg;
    }

    public void setDjjg(Double djjg) {
        this.djjg = djjg;
    }

    public String getFkxs() {
        return fkxs;
    }

    public void setFkxs(String fkxs) {
        this.fkxs = fkxs;
    }

    public Integer getFkqx() {
        return fkqx;
    }

    public void setFkqx(Integer fkqx) {
        this.fkqx = fkqx;
    }

    public Integer getJfqx() {
        return jfqx;
    }

    public void setJfqx(Integer jfqx) {
        this.jfqx = jfqx;
    }

    public Integer getZldqtqtcts() {
        return zldqtqtcts;
    }

    public void setZldqtqtcts(Integer zldqtqtcts) {
        this.zldqtqtcts = zldqtqtcts;
    }

    public Integer getZldqtqdfts() {
        return zldqtqdfts;
    }

    public void setZldqtqdfts(Integer zldqtqdfts) {
        this.zldqtqdfts = zldqtqdfts;
    }

    public Integer getJfzzhttqtcts() {
        return jfzzhttqtcts;
    }

    public void setJfzzhttqtcts(Integer jfzzhttqtcts) {
        this.jfzzhttqtcts = jfzzhttqtcts;
    }

    public Integer getYfzzhttqtcts() {
        return yfzzhttqtcts;
    }

    public void setYfzzhttqtcts(Integer yfzzhttqtcts) {
        this.yfzzhttqtcts = yfzzhttqtcts;
    }

    public Double getJfwyjbl() {
        return jfwyjbl;
    }

    public void setJfwyjbl(Double jfwyjbl) {
        this.jfwyjbl = jfwyjbl;
    }

    public Double getYfwyjbl() {
        return yfwyjbl;
    }

    public void setYfwyjbl(Double yfwyjbl) {
        this.yfwyjbl = yfwyjbl;
    }

    public String getHtzzyd() {
        return htzzyd;
    }

    public void setHtzzyd(String htzzyd) {
        this.htzzyd = htzzyd;
    }

    public Integer getBldjqx() {
        return bldjqx;
    }

    public void setBldjqx(Integer bldjqx) {
        this.bldjqx = bldjqx;
    }

    public String getBldjjg() {
        return bldjjg;
    }

    public void setBldjjg(String bldjjg) {
        this.bldjjg = bldjjg;
    }

    public String getQtyd() {
        return qtyd;
    }

    public void setQtyd(String qtyd) {
        this.qtyd = qtyd;
    }

    public String getFdcjjjgbh() {
        return fdcjjjgbh;
    }

    public void setFdcjjjgbh(String fdcjjjgbh) {
        this.fdcjjjgbh = fdcjjjgbh;
    }

    public String getFdcjjrbh() {
        return fdcjjrbh;
    }

    public void setFdcjjrbh(String fdcjjrbh) {
        this.fdcjjrbh = fdcjjrbh;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getHtbz() {
        return htbz;
    }

    public void setHtbz(String htbz) {
        this.htbz = htbz;
    }
}
